@@ -481,10 +481,22 @@ print_request (SoupLogger *logger, SoupMessage *msg,
 		return;
 
 	if (!soup_message_headers_get_one (msg->request_headers, "Host")) {
+		char *uri_host;
+
+		if (strchr (uri->host, ':'))
+			uri_host = g_strdup_printf ("[%s]", uri->host);
+		else if (g_hostname_is_non_ascii (uri->host))
+			uri_host = g_hostname_to_ascii (uri->host);
+		else
+			uri_host = uri->host;
+
 		soup_logger_print (logger, SOUP_LOGGER_LOG_HEADERS, '>',
-				   "Host: %s%c%u", uri->host,
+				   "Host: %s%c%u", uri_host,
 				   soup_uri_uses_default_port (uri) ? '\0' : ':',
 				   uri->port);
+
+		if (uri_host != uri->host)
+			g_free (uri_host);
 	}
 	soup_message_headers_iter_init (&iter, msg->request_headers);
 	while (soup_message_headers_iter_next (&iter, &name, &value)) {
