@@ -38,10 +38,12 @@ typedef struct {
 
 	GTlsCertificate      *tls_certificate;
 	GTlsCertificateFlags  tls_errors;
+
+	SoupRequest       *request;
 } SoupMessagePrivate;
 #define SOUP_MESSAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SOUP_TYPE_MESSAGE, SoupMessagePrivate))
 
-void             soup_message_cleanup_response (SoupMessage      *req);
+void             soup_message_cleanup_response (SoupMessage      *msg);
 
 
 typedef void     (*SoupMessageGetHeadersFn)  (SoupMessage      *msg,
@@ -52,7 +54,8 @@ typedef guint    (*SoupMessageParseHeadersFn)(SoupMessage      *msg,
 					      char             *headers,
 					      guint             header_len,
 					      SoupEncoding     *encoding,
-					      gpointer          user_data);
+					      gpointer          user_data,
+					      GError          **error);
 typedef void     (*SoupMessageCompletionFn)  (SoupMessage      *msg,
 					      gpointer          user_data);
 
@@ -60,7 +63,7 @@ typedef void     (*SoupMessageCompletionFn)  (SoupMessage      *msg,
 void soup_message_send_request (SoupMessageQueueItem      *item,
 				SoupMessageCompletionFn    completion_cb,
 				gpointer                   user_data);
-void soup_message_read_request (SoupMessage               *req,
+void soup_message_read_request (SoupMessage               *msg,
 				SoupSocket                *sock,
 				SoupMessageCompletionFn    completion_cb,
 				gpointer                   user_data);
@@ -132,4 +135,7 @@ GInputStream *soup_message_setup_body_istream (GInputStream *body_stream,
 					       SoupSession *session,
 					       SoupProcessingStage start_at_stage);
 
+void soup_message_set_soup_request (SoupMessage *msg,
+				    SoupRequest *req);
+
 #endif /* SOUP_MESSAGE_PRIVATE_H */
