@@ -67,19 +67,7 @@ queue_message_restarted (SoupMessage *msg, gpointer user_data)
 		item->proxy_uri = NULL;
 	}
 
-	if (item->conn &&
-	    (!soup_message_is_keepalive (msg) ||
-	     SOUP_STATUS_IS_REDIRECTION (msg->status_code))) {
-		if (soup_connection_get_state (item->conn) == SOUP_CONNECTION_IN_USE)
-			soup_connection_set_state (item->conn, SOUP_CONNECTION_IDLE);
-		soup_message_queue_item_set_connection (item, NULL);
-	}
-
-	soup_message_cleanup_response (msg);
-
 	g_cancellable_reset (item->cancellable);
-
-	item->state = SOUP_MESSAGE_STARTING;
 }
 
 /**
@@ -163,6 +151,8 @@ soup_message_queue_item_unref (SoupMessageQueueItem *item)
 		return;
 	}
 
+	g_warn_if_fail (item->conn == NULL);
+
 	/* OK, @item is dead. Rewrite @queue around it */
 	if (item->prev)
 		item->prev->next = item->next;
@@ -181,49 +171,16 @@ soup_message_queue_item_unref (SoupMessageQueueItem *item)
 	g_object_unref (item->session);
 	g_object_unref (item->msg);
 	g_object_unref (item->cancellable);
-	if (item->proxy_addr)
-		g_object_unref (item->proxy_addr);
-	if (item->proxy_uri)
-		soup_uri_free (item->proxy_uri);
-	if (item->task)
-		g_object_unref (item->task);
+	g_clear_object (&item->proxy_addr);
+	g_clear_pointer (&item->proxy_uri, soup_uri_free);
+	g_clear_object (&item->task);
 	if (item->io_source) {
 		g_source_destroy (item->io_source);
 		g_source_unref (item->io_source);
 	}
-	soup_message_queue_item_set_connection (item, NULL);
 	g_slice_free (SoupMessageQueueItem, item);
 }
 
-static void
-proxy_connection_event (SoupConnection      *conn,
-			GSocketClientEvent   event,
-			GIOStream           *connection,
-			gpointer             user_data)
-{
-	SoupMessageQueueItem *item = user_data;
-
-	soup_message_network_event (item->msg, event, connection);
-}
-
-void
-soup_message_queue_item_set_connection (SoupMessageQueueItem *item,
-					SoupConnection       *conn)
-{
-	if (item->conn) {
-		g_signal_handlers_disconnect_by_func (item->conn, proxy_connection_event, item);
-		g_object_unref (item->conn);
-	}
-
-	item->conn = conn;
-
-	if (item->conn) {
-		g_object_ref (item->conn);
-		g_signal_connect (item->conn, "event",
-				  G_CALLBACK (proxy_connection_event), item);
-	}
-}
-
 /**
  * soup_message_queue_lookup:
  * @queue: a #SoupMessageQueue
