@@ -208,9 +208,8 @@ do_message_api_test (SoupSession *session, SoupURI *base_uri, int n)
 static void
 do_request_api_test (SoupSession *session, SoupURI *base_uri, int n)
 {
-	SoupRequester *requester = (SoupRequester *)soup_session_get_feature (session, SOUP_TYPE_REQUESTER);
 	SoupURI *uri;
-	SoupRequest *req;
+	SoupRequestHTTP *reqh;
 	SoupMessage *msg;
 	TestRequest *treq;
 	GInputStream *stream;
@@ -226,9 +225,11 @@ do_request_api_test (SoupSession *session, SoupURI *base_uri, int n)
 		final_status = tests[n].final_status;
 
 	uri = soup_uri_new_with_base (base_uri, tests[n].requests[0].path);
-	req = soup_requester_request_uri (requester, uri, &error);
+	reqh = soup_session_request_http_uri (session,
+					      tests[n].requests[0].method,
+					      uri, &error);
 	soup_uri_free (uri);
-	if (!req) {
+	if (!reqh) {
 		debug_printf (1, "    could not create request: %s\n",
 			      error->message);
 		g_error_free (error);
@@ -237,11 +238,7 @@ do_request_api_test (SoupSession *session, SoupURI *base_uri, int n)
 		return;
 	}
 
-	msg = soup_request_http_get_message (SOUP_REQUEST_HTTP (req));
-	g_object_set (G_OBJECT (msg),
-		      SOUP_MESSAGE_METHOD, tests[n].requests[0].method,
-		      NULL);
-
+	msg = soup_request_http_get_message (reqh);
 	if (msg->method == SOUP_METHOD_POST) {
 		soup_message_set_request (msg, "text/plain",
 					  SOUP_MEMORY_STATIC,
@@ -255,7 +252,7 @@ do_request_api_test (SoupSession *session, SoupURI *base_uri, int n)
 	g_signal_connect (msg, "restarted",
 			  G_CALLBACK (restarted), &treq);
 
-	stream = soup_test_request_send (req, NULL, &error);
+	stream = soup_test_request_send (SOUP_REQUEST (reqh), NULL, &error);
 
 	if (SOUP_STATUS_IS_TRANSPORT_ERROR (final_status)) {
 		if (stream) {
@@ -274,7 +271,7 @@ do_request_api_test (SoupSession *session, SoupURI *base_uri, int n)
 
 		g_error_free (error);
 		g_object_unref (msg);
-		g_object_unref (req);
+		g_object_unref (reqh);
 		debug_printf (2, "\n");
 		return;
 	} else if (!stream) {
@@ -282,13 +279,13 @@ do_request_api_test (SoupSession *session, SoupURI *base_uri, int n)
 			      error->message);
 		g_error_free (error);
 		g_object_unref (msg);
-		g_object_unref (req);
+		g_object_unref (reqh);
 		errors++;
 		debug_printf (2, "\n");
 		return;
 	}
 
-	soup_test_request_close_stream (req, stream, NULL, &error);
+	soup_test_request_close_stream (SOUP_REQUEST (reqh), stream, NULL, &error);
 	if (error) {
 		debug_printf (1, "    could not close stream: %s\n",
 			      error->message);
@@ -304,7 +301,7 @@ do_request_api_test (SoupSession *session, SoupURI *base_uri, int n)
 	}
 
 	g_object_unref (msg);
-	g_object_unref (req);
+	g_object_unref (reqh);
 	debug_printf (2, "\n");
 }
 
@@ -315,7 +312,6 @@ do_redirect_tests (SoupURI *base_uri)
 	int n;
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC,
-					 SOUP_SESSION_ADD_FEATURE_BY_TYPE, SOUP_TYPE_REQUESTER,
 					 SOUP_SESSION_USE_THREAD_CONTEXT, TRUE,
 					 NULL);
 	debug_printf (1, "Async session, SoupMessage\n");
@@ -326,9 +322,7 @@ do_redirect_tests (SoupURI *base_uri)
 		do_request_api_test (session, base_uri, n);
 	soup_test_session_abort_unref (session);
 
-	session = soup_test_session_new (SOUP_TYPE_SESSION_SYNC,
-					 SOUP_SESSION_ADD_FEATURE_BY_TYPE, SOUP_TYPE_REQUESTER,
-					 NULL);
+	session = soup_test_session_new (SOUP_TYPE_SESSION_SYNC, NULL);
 	debug_printf (1, "\nSync session, SoupMessage\n");
 	for (n = 0; n < n_tests; n++)
 		do_message_api_test (session, base_uri, n);
