@@ -3,6 +3,9 @@
  * Copyright (C) 2011 Red Hat, Inc.
  */
 
+/* Kill SoupRequester-related deprecation warnings */
+#define SOUP_VERSION_MIN_REQUIRED SOUP_VERSION_2_40
+
 #include "test-utils.h"
 
 SoupServer *server;
@@ -142,10 +145,10 @@ test_read_ready (GObject *source, GAsyncResult *res, gpointer user_data)
 static void
 auth_test_sent (GObject *source, GAsyncResult *res, gpointer user_data)
 {
+	SoupRequestHTTP *http = SOUP_REQUEST_HTTP (source);
 	RequestData *data = user_data;
 	GInputStream *stream;
 	GError *error = NULL;
-	SoupMessage *msg;
 	const char *content_type;
 
 	stream = soup_request_send_finish (SOUP_REQUEST (source), res, &error);
@@ -157,15 +160,14 @@ auth_test_sent (GObject *source, GAsyncResult *res, gpointer user_data)
 		return;
 	}
 
-	msg = soup_request_http_get_message (SOUP_REQUEST_HTTP (source));
-	if (msg->status_code != SOUP_STATUS_UNAUTHORIZED) {
-		debug_printf (1, "    GET failed: %d %s\n", msg->status_code,
-			      msg->reason_phrase);
+
+	if (http->status_code != SOUP_STATUS_UNAUTHORIZED) {
+		debug_printf (1, "    GET failed: %d %s\n", http->status_code,
+			      http->reason_phrase);
 		errors++;
 		g_main_loop_quit (loop);
 		return;
 	}
-	g_object_unref (msg);
 
 	content_type = soup_request_get_content_type (SOUP_REQUEST (source));
 	if (g_strcmp0 (content_type, "text/html") != 0) {
@@ -252,16 +254,23 @@ do_async_test (SoupSession *session, SoupURI *uri,
 	SoupMessage *msg;
 	RequestData data;
 
-	requester = SOUP_REQUESTER (soup_session_get_feature (session, SOUP_TYPE_REQUESTER));
+	if (SOUP_IS_SESSION_ASYNC (session))
+		requester = SOUP_REQUESTER (soup_session_get_feature (session, SOUP_TYPE_REQUESTER));
+	else
+		requester = NULL;
 
 	data.body = g_string_new (NULL);
 	data.cancel = cancel;
-	request = soup_requester_request_uri (requester, uri, NULL);
-	msg = soup_request_http_get_message (SOUP_REQUEST_HTTP (request));
+	if (requester)
+		request = soup_requester_request_uri (requester, uri, NULL);
+	else
+		request = soup_session_request_uri (session, uri, NULL);
 
 	if (cancel) {
+		msg = soup_request_http_get_message (SOUP_REQUEST_HTTP (request));
 		g_signal_connect (msg, "got-headers",
 				  G_CALLBACK (cancel_message), session);
+		g_object_unref (msg);
 	}
 
 	started_id = g_signal_connect (session, "request-started",
@@ -269,7 +278,6 @@ do_async_test (SoupSession *session, SoupURI *uri,
 				       &socket);
 
 	soup_request_send_async (request, NULL, callback, &data);
-	g_object_unref (request);
 
 	loop = g_main_loop_new (soup_session_get_async_context (session), TRUE);
 	g_main_loop_run (loop);
@@ -277,16 +285,16 @@ do_async_test (SoupSession *session, SoupURI *uri,
 
 	g_signal_handler_disconnect (session, started_id);
 
-	if (msg->status_code != expected_status) {
+	if (SOUP_REQUEST_HTTP (request)->status_code != expected_status) {
 		debug_printf (1, "    GET failed: %d %s (expected %d)\n",
 			      msg->status_code, msg->reason_phrase,
 			      expected_status);
-		g_object_unref (msg);
 		g_object_unref (socket);
+		g_object_unref (request);
 		errors++;
 		return;
 	}
-	g_object_unref (msg);
+	g_object_unref (request);
 
 	if (!expected_response) {
 		if (data.body->len) {
@@ -326,9 +334,11 @@ do_test_for_thread_and_context (SoupSession *session, const char *base_uri)
 	SoupRequester *requester;
 	SoupURI *uri;
 
-	requester = soup_requester_new ();
-	soup_session_add_feature (session, SOUP_SESSION_FEATURE (requester));
-	g_object_unref (requester);
+	if (SOUP_IS_SESSION_ASYNC (session)) {
+		requester = soup_requester_new ();
+		soup_session_add_feature (session, SOUP_SESSION_FEATURE (requester));
+		g_object_unref (requester);
+	}
 	soup_session_add_feature_by_type (session, SOUP_TYPE_CONTENT_SNIFFER);
 
 	debug_printf (1, "  basic test\n");
@@ -372,21 +382,22 @@ do_test_for_thread_and_context (SoupSession *session, const char *base_uri)
 }
 
 static void
-do_simple_test (const char *uri)
+do_simple_test (const char *uri, gboolean plain_session)
 {
 	SoupSession *session;
 
-	debug_printf (1, "Simple streaming test\n");
+	debug_printf (1, "Simple streaming test with %s\n",
+		      plain_session ? "SoupSession" : "SoupSessionAsync");
 
-	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC,
+	session = soup_test_session_new (plain_session ? SOUP_TYPE_SESSION : SOUP_TYPE_SESSION_ASYNC,
 					 SOUP_SESSION_USE_THREAD_CONTEXT, TRUE,
 					 NULL);
 	do_test_for_thread_and_context (session, uri);
 	soup_test_session_abort_unref (session);
 }
 
-static gpointer
-do_test_with_context (const char *uri)
+static void
+do_test_with_context_and_type (const char *uri, gboolean plain_session)
 {
 	GMainContext *async_context;
 	SoupSession *session;
@@ -394,7 +405,7 @@ do_test_with_context (const char *uri)
 	async_context = g_main_context_new ();
 	g_main_context_push_thread_default (async_context);
 
-	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC,
+	session = soup_test_session_new (plain_session ? SOUP_TYPE_SESSION : SOUP_TYPE_SESSION_ASYNC,
 					 SOUP_SESSION_ASYNC_CONTEXT, async_context,
 					 SOUP_SESSION_USE_THREAD_CONTEXT, TRUE,
 					 NULL);
@@ -404,25 +415,43 @@ do_test_with_context (const char *uri)
 
 	g_main_context_pop_thread_default (async_context);
 	g_main_context_unref (async_context);
+}
+
+static gpointer
+do_test_with_context (gpointer uri)
+{
+	do_test_with_context_and_type (uri, FALSE);
+	return NULL;
+}
+
+static gpointer
+do_plain_test_with_context (gpointer uri)
+{
+	do_test_with_context_and_type (uri, TRUE);
 	return NULL;
 }
 
 static void
-do_context_test (const char *uri)
+do_context_test (const char *uri, gboolean plain_session)
 {
-	debug_printf (1, "Streaming with a non-default-context\n");
-	do_test_with_context (uri);
+	debug_printf (1, "Streaming with a non-default-context with %s\n",
+		      plain_session ? "SoupSession" : "SoupSessionAsync");
+	if (plain_session)
+		do_plain_test_with_context ((gpointer)uri);
+	else
+		do_test_with_context ((gpointer)uri);
 }
 
 static void
-do_thread_test (const char *uri)
+do_thread_test (const char *uri, gboolean plain_session)
 {
 	GThread *thread;
 
-	debug_printf (1, "Streaming in another thread\n");
+	debug_printf (1, "Streaming in another thread with %s\n",
+		      plain_session ? "SoupSession" : "SoupSessionAsync");
 
 	thread = g_thread_new ("do_test_with_context",
-			       (GThreadFunc)do_test_with_context,
+			       plain_session ? do_plain_test_with_context : do_test_with_context,
 			       (gpointer)uri);
 	g_thread_join (thread);
 }
@@ -441,10 +470,11 @@ do_sync_request (SoupSession *session, SoupRequest *request,
 	guint started_id;
 	SoupSocket *socket = NULL;
 
-	msg = soup_request_http_get_message (SOUP_REQUEST_HTTP (request));
 	if (cancel) {
+		msg = soup_request_http_get_message (SOUP_REQUEST_HTTP (request));
 		g_signal_connect (msg, "got-headers",
 				  G_CALLBACK (cancel_message), session);
+		g_object_unref (msg);
 	}
 
 	started_id = g_signal_connect (session, "request-started",
@@ -464,29 +494,25 @@ do_sync_request (SoupSession *session, SoupRequest *request,
 			errors++;
 		}
 		g_clear_error (&error);
-		g_object_unref (msg);
 		g_object_unref (socket);
 		return;
 	} else if (!in) {
 		debug_printf (1, "    soup_request_send failed: %s\n",
 			      error->message);
-		g_object_unref (msg);
 		g_clear_error (&error);
 		g_object_unref (socket);
 		errors++;
 		return;
 	}
 
-	if (msg->status_code != expected_status) {
+	if (SOUP_REQUEST_HTTP (request)->status_code != expected_status) {
 		debug_printf (1, "    GET failed: %d %s\n", msg->status_code,
 			      msg->reason_phrase);
-		g_object_unref (msg);
 		g_object_unref (in);
 		g_object_unref (socket);
 		errors++;
 		return;
 	}
-	g_object_unref (msg);
 
 	body = g_string_new (NULL);
 	do {
@@ -542,24 +568,30 @@ do_sync_request (SoupSession *session, SoupRequest *request,
 }
 
 static void
-do_sync_test (const char *uri_string)
+do_sync_test (const char *uri_string, gboolean plain_session)
 {
 	SoupSession *session;
 	SoupRequester *requester;
 	SoupRequest *request;
 	SoupURI *uri;
 
-	debug_printf (1, "Sync streaming\n");
+	debug_printf (1, "Sync streaming with %s\n",
+		      plain_session ? "SoupSession" : "SoupSessionSync");
 
-	session = soup_test_session_new (SOUP_TYPE_SESSION_SYNC, NULL);
-	requester = soup_requester_new ();
-	soup_session_add_feature (session, SOUP_SESSION_FEATURE (requester));
-	g_object_unref (requester);
+	session = soup_test_session_new (plain_session ? SOUP_TYPE_SESSION : SOUP_TYPE_SESSION_SYNC, NULL);
+	if (!plain_session) {
+		requester = soup_requester_new ();
+		soup_session_add_feature (session, SOUP_SESSION_FEATURE (requester));
+		g_object_unref (requester);
+	}
 
 	uri = soup_uri_new (uri_string);
 
 	debug_printf (1, "  basic test\n");
-	request = soup_requester_request_uri (requester, uri, NULL);
+	if (plain_session)
+		request = soup_session_request_uri (session, uri, NULL);
+	else
+		request = soup_requester_request_uri (requester, uri, NULL);
 	do_sync_request (session, request,
 			 SOUP_STATUS_OK, response,
 			 TRUE, FALSE);
@@ -567,7 +599,10 @@ do_sync_test (const char *uri_string)
 
 	debug_printf (1, "  chunked test\n");
 	soup_uri_set_path (uri, "/chunked");
-	request = soup_requester_request_uri (requester, uri, NULL);
+	if (plain_session)
+		request = soup_session_request_uri (session, uri, NULL);
+	else
+		request = soup_requester_request_uri (requester, uri, NULL);
 	do_sync_request (session, request,
 			 SOUP_STATUS_OK, response,
 			 TRUE, FALSE);
@@ -575,7 +610,10 @@ do_sync_test (const char *uri_string)
 
 	debug_printf (1, "  auth test\n");
 	soup_uri_set_path (uri, "/auth");
-	request = soup_requester_request_uri (requester, uri, NULL);
+	if (plain_session)
+		request = soup_session_request_uri (session, uri, NULL);
+	else
+		request = soup_requester_request_uri (requester, uri, NULL);
 	do_sync_request (session, request,
 			 SOUP_STATUS_UNAUTHORIZED, auth_response,
 			 TRUE, FALSE);
@@ -583,7 +621,10 @@ do_sync_test (const char *uri_string)
 
 	debug_printf (1, "  non-persistent test\n");
 	soup_uri_set_path (uri, "/non-persistent");
-	request = soup_requester_request_uri (requester, uri, NULL);
+	if (plain_session)
+		request = soup_session_request_uri (session, uri, NULL);
+	else
+		request = soup_requester_request_uri (requester, uri, NULL);
 	do_sync_request (session, request,
 			 SOUP_STATUS_OK, response,
 			 FALSE, FALSE);
@@ -591,7 +632,10 @@ do_sync_test (const char *uri_string)
 
 	debug_printf (1, "  cancel test\n");
 	soup_uri_set_path (uri, "/");
-	request = soup_requester_request_uri (requester, uri, NULL);
+	if (plain_session)
+		request = soup_session_request_uri (session, uri, NULL);
+	else
+		request = soup_requester_request_uri (requester, uri, NULL);
 	do_sync_request (session, request,
 			 SOUP_STATUS_FORBIDDEN, NULL,
 			 TRUE, TRUE);
@@ -614,10 +658,15 @@ main (int argc, char **argv)
 
 	uri = g_strdup_printf ("http://127.0.0.1:%u/foo", soup_server_get_port (server));
 
-	do_simple_test (uri);
-	do_thread_test (uri);
-	do_context_test (uri);
-	do_sync_test (uri);
+	do_simple_test (uri, FALSE);
+	do_thread_test (uri, FALSE);
+	do_context_test (uri, FALSE);
+	do_sync_test (uri, FALSE);
+
+	do_simple_test (uri, TRUE);
+	do_thread_test (uri, TRUE);
+	do_context_test (uri, TRUE);
+	do_sync_test (uri, TRUE);
 
 	g_free (uri);
 	soup_buffer_free (response);
